[−][src]Enum vampirc_uci::uci::UciMessage
An enumeration type containing representations for all messages supported by the UCI protocol.
Variants
The uci engine-bound message.
Debug(bool)The debug engine-bound message. Its internal property specifies whether debug mode should be enabled (true),
or disabled (false).
The isready engine-bound message.
The register engine-bound message.
Fields of Register
The position engine-bound message.
Fields of Position
The setoption engine-bound message.
Fields of SetOption
The ucinewgame engine-bound message.
The stop engine-bound message.
The ponderhit engine-bound message.
The quit engine-bound message.
The go engine-bound message.
Fields of Go
time_control: Option<UciTimeControl>Time-control-related go parameters (sub-commands).
search_control: Option<UciSearchControl>Search-related go parameters (sub-commands).
The id GUI-bound message.
Fields of Id
The uciok GUI-bound message.
The readyok GUI-bound message.
The bestmove GUI-bound message.
Fields of BestMove
CopyProtection(ProtectionState)The copyprotection GUI-bound message.
Registration(ProtectionState)The registration GUI-bound message.
Option(UciOptionConfig)The option GUI-bound message.
Info(Vec<UciInfoAttribute>)The info GUI-bound message.
Indicating unknown message.
Methods
impl UciMessage[src]
pub fn register_later() -> UciMessage[src]
Constructs a register later UciMessage::Register message.
pub fn register_code(name: &str, code: &str) -> UciMessage[src]
Constructs a register <code> <name> UciMessage::Register message.
pub fn go() -> UciMessage[src]
Constructs an empty UciMessage::Register message.
pub fn go_ponder() -> UciMessage[src]
Construct a go ponder UciMessage::Register message.
pub fn go_infinite() -> UciMessage[src]
Constructs a go infinite UciMessage::Register message.
pub fn go_movetime(milliseconds: u64) -> UciMessage[src]
Constructs a go movetime <milliseconds> UciMessage::Register message, with
milliseconds as the argument.
pub fn id_name(name: &str) -> UciMessage[src]
Constructs an id <name> GUI-bound message.
pub fn id_author(author: &str) -> UciMessage[src]
Constructs an id <name> GUI-bound message.
pub fn best_move(best_move: UciMove) -> UciMessage[src]
Constructs a bestmove GUI-bound message without the ponder move.
pub fn best_move_with_ponder(best_move: UciMove, ponder: UciMove) -> UciMessage[src]
Constructs a bestmove GUI-bound message with the ponder move.
pub fn info_string(s: String) -> UciMessage[src]
Constructs an info string ... message.
pub fn as_bool(&self) -> Option<bool>[src]
If this UciMessage is a UciMessage::SetOption and the value of that option is a bool, this method returns
the bool value, otherwise it returns None.
pub fn as_i32(&self) -> Option<i32>[src]
If this UciMessage is a UciMessage::SetOption and the value of that option is an integer, this method
returns the i32 value of the integer, otherwise it returns None.
pub fn is_unknown(&self) -> bool[src]
Return true if this UciMessage is of variant UnknownMessage.