[−][src]Enum vampirc_uci::uci::UciTimeControl
This enum represents the possible variants of the go UCI message that deal with the chess game's time controls
and the engine's thinking time.
Variants
The go ponder message.
The go infinite message.
The information about the game's time controls.
Fields of TimeLeft
white_time: Option<u64>White's time on the clock, in milliseconds.
black_time: Option<u64>Black's time on the clock, in milliseconds.
white_increment: Option<u64>White's increment per move, in milliseconds.
black_increment: Option<u64>Black's increment per move, in milliseconds.
moves_to_go: Option<u8>The number of moves to go to the next time control.
MoveTime(u64)Specifies how much time the engine should think about the move, in milliseconds.
Methods
impl UciTimeControl[src]
pub fn time_left() -> UciTimeControl[src]
Returns a UciTimeControl::TimeLeft with all members set to None.