UciSearchControl

Struct UciSearchControl 

pub struct UciSearchControl {
    pub search_moves: Vec<UciMove>,
    pub mate: Option<u8>,
    pub depth: Option<u8>,
    pub nodes: Option<u64>,
}
A struct that controls the engine’s (non-time-related) search settings.

Fields

search_moves: Vec<UciMove>

Limits the search to these moves.

mate: Option<u8>

Search for mate in this many moves.

depth: Option<u8>

Search to this ply depth.

nodes: Option<u64>

Search no more than this many nodes (positions).

Implementations

Source

impl UciSearchControl

pub fn depth(depth: u8) -> UciSearchControl

Creates an UciSearchControl with depth set to the parameter and everything else set to empty or None.

pub fn mate(mate: u8) -> UciSearchControl

Creates an UciSearchControl with mate set to the parameter and everything else set to empty or None.

pub fn nodes(nodes: u64) -> UciSearchControl

Creates an UciSearchControl with nodes set to the parameter and everything else set to empty or None.

pub fn is_empty(&self) -> bool

Returns true if all of the struct’s settings are either None or empty.